#ifndef SEARCHWIDGET_H
#define SEARCHWIDGET_H

#include "BSearchWidget.h"

class QtellaSub;

#if !defined(_WIN32)
using namespace std;
#endif

class SearchWidget : public BSearchWidget
{ 
    Q_OBJECT

 public:
    SearchWidget( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SearchWidget();

 signals:
    void doubleClicked(QListViewItem*);
    void rightButton(QListViewItem*, const QPoint&, int);

 public slots:
    virtual void slotDoubleClick(QListViewItem*);
    virtual void slotRightButton(QListViewItem*, const QPoint&, int);

 private:
    QtellaSub *parent; 
};

#endif // SEARCHWIDGET_H
